Name:          mina-ftpserver
Version:       1.0.6
Release:       %mkrel 2
Summary:       A 100% pure Java FTP server
Group:         Development/Java
License:       ASL 2.0
URL:           http://mina.apache.org/ftpserver/
Source0:       http://www.apache.org/dist/mina/ftpserver/%{version}/ftpserver-%{version}-src.tar.gz

# fix apache-rat-plugin aId and gId
# fix plugins gId, remove some warnings
Patch0:        ftpserver-%{version}-parent-pom.patch
# fix plugins aId and gId, remove some warnings
Patch1:        ftpserver-%{version}-ftplet-api-pom.patch
# fix bundle plugin configuration
# fix apache-rat-plugin aId and gId
Patch2:        ftpserver-%{version}-core-pom.patch

BuildRequires: java-devel
BuildRequires: jpackage-utils

BuildRequires: apache-mina
BuildRequires: felix-osgi-core
BuildRequires: slf4j
BuildRequires: springframework-context
BuildRequires: apache-resource-bundles 
# test deps
BuildRequires: apache-commons-codec
BuildRequires: apache-commons-net
BuildRequires: hsqldb
BuildRequires: junit
BuildRequires: log4j

BuildRequires: maven
BuildRequires: maven-compiler-plugin
BuildRequires: maven-enforcer-plugin
BuildRequires: maven-install-plugin
BuildRequires: maven-javadoc-plugin
BuildRequires: maven-plugin-bundle
BuildRequires: maven-remote-resources-plugin
BuildRequires: maven-resources-plugin
BuildRequires: maven-source-plugin
BuildRequires: maven-surefire-plugin
BuildRequires: maven-surefire-provider-junit4

Requires:      apache-mina
Requires:      slf4j
Requires:      springframework-context

Requires:      java
Requires:      jpackage-utils
BuildArch:     noarch

%description
The Apache FtpServer is a 100% pure Java FTP server. It's
designed to be a complete and portable FTP server engine
solution based on currently available open protocols.
FtpServer can be run standalone as a Windows service or
Unix/Linux daemon, or embedded into a Java application.
We also provide support for integration within Spring
applications and provide our releases as OSGi bundles.

The default network support is based on Apache MINA, a
high performance asynchronous IO library. Using MINA,
FtpServer can scale to a large number of concurrent users.

It is also an FTP application platform. We have developed
a Java API to let you write Java code to process FTP event
notifications that we call the Ftplet API. Apache FtpServer
provides an implementation of an FTP server to support this API.

%package examples
Group:         Development/Java
Summary:       Apache FtpServer Examples
Requires:      %{name} = %{version}-%{release}
Requires:      felix-osgi-core

%description examples
This package provides:
* FtpServer OSGi Ftplet service example
* FtpServer OSGi Spring-DM example

%package javadoc
Group:         Development/Java
Summary:       Javadoc for %{name}
Requires:      jpackage-utils

%description javadoc
This package contains javadoc for %{name}.

%prep
%setup -q -n apache-ftpserver-%{version}
mv src/* .
find . -name "*.bat" -delete
find . -name "*.class" -delete
find . -name "*.exe" -delete
find . -name "*.jar" -delete

%patch0 -p0
%patch1 -p0
%patch2 -p0

sed -i "s|<module>distribution</module>|<!--module>distribution</module-->|" pom.xml

# require org.mortbay.jetty maven-jetty-plugin 6.1.8
sed -i "s|<module>ftpserver-example-spring-war</module>|<!--module>ftpserver-example-spring-war</module-->|" examples/pom.xml
# explicit felix-osgi-core
sed -i "s|<groupId>org.osgi</groupId>|<groupId>org.apache.felix</groupId>|" examples/ftpserver-osgi-ftplet-service/pom.xml
sed -i "s|<artifactId>osgi_R4_core</artifactId>|<artifactId>org.osgi.core</artifactId>|" examples/ftpserver-osgi-ftplet-service/pom.xml

%build

mvn-rpmbuild -Dproject.build.sourceEncoding=UTF-8 -Dmaven.test.skip=true install javadoc:aggregate

%install

mkdir -p %{buildroot}%{_mavenpomdir}
mkdir -p %{buildroot}%{_javadir}/%{name}

install -pm 644 pom.xml %{buildroot}%{_mavenpomdir}/JPP.%{name}-parent.pom
%add_maven_depmap JPP.%{name}-parent.pom

install -m 644 core/target/ftpserver-core-%{version}.jar %{buildroot}%{_javadir}/%{name}/ftpserver-core.jar
install -pm 644 core/pom.xml %{buildroot}%{_mavenpomdir}/JPP.%{name}-ftpserver-core.pom
%add_maven_depmap JPP.%{name}-ftpserver-core.pom %{name}/ftpserver-core.jar

install -m 644 ftplet-api/target/ftplet-api-%{version}.jar %{buildroot}%{_javadir}/%{name}/ftplet-api.jar
install -pm 644 ftplet-api/pom.xml %{buildroot}%{_mavenpomdir}/JPP.%{name}-ftplet-api.pom
%add_maven_depmap JPP.%{name}-ftplet-api.pom %{name}/ftplet-api.jar

install -pm 644 examples/pom.xml %{buildroot}%{_mavenpomdir}/JPP.%{name}-examples.pom
%add_maven_depmap JPP.%{name}-examples.pom -f examples

for m in \
  ftpserver-osgi-ftplet-service \
  ftpserver-osgi-spring-service;do
    install -m 644 examples/${m}/target/${m}-%{version}.jar %{buildroot}%{_javadir}/%{name}/${m}.jar
    install -pm 644 examples/${m}/pom.xml %{buildroot}%{_mavenpomdir}/JPP.%{name}-${m}.pom
    %add_maven_depmap JPP.%{name}-${m}.pom %{name}/${m}.jar -f examples
done

mkdir -p %{buildroot}%{_javadocdir}/%{name}
cp -rp target/site/apidocs/* %{buildroot}%{_javadocdir}/%{name}

%files
%dir %{_javadir}/%{name}
%{_javadir}/%{name}/ftplet-api.jar
%{_javadir}/%{name}/ftpserver-core.jar
%{_mavenpomdir}/JPP.%{name}-ftpserver-core.pom
%{_mavenpomdir}/JPP.%{name}-ftplet-api.pom
%{_mavenpomdir}/JPP.%{name}-parent.pom
%{_mavendepmapfragdir}/%{name}
%doc LICENSE NOTICE

%files examples
%{_javadir}/%{name}/ftpserver-osgi-ftplet-service.jar
%{_javadir}/%{name}/ftpserver-osgi-spring-service.jar
%{_mavenpomdir}/JPP.%{name}-examples.pom
%{_mavenpomdir}/JPP.%{name}-ftpserver-osgi-ftplet-service.pom
%{_mavenpomdir}/JPP.%{name}-ftpserver-osgi-spring-service.pom
%{_mavendepmapfragdir}/%{name}-examples
%doc LICENSE NOTICE

%files javadoc
%{_javadocdir}/%{name}
%doc LICENSE NOTICE



%changelog

* Sat Jan 12 2013 umeabot <umeabot> 1.0.6-2.mga3
+ Revision: 360085
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Sep 17 2012 dmorgan <dmorgan> 1.0.6-1.mga3
+ Revision: 294744
- imported package mina-ftpserver

